@@ -1,14 +1,13 @@
 package Dancer::Session;
 our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: session engine for the Dancer framework
-$Dancer::Session::VERSION = '1.3137'; # TRIAL
+$Dancer::Session::VERSION = '1.3139'; # TRIAL
 use strict;
 use warnings;
 
 use Carp;
 use Dancer::Cookies;
 use Dancer::Engine;
-use Dancer::SharedData;
 
 # Singleton representing the session engine class to use
 my $ENGINE = undef;
@@ -27,13 +26,13 @@ sub get_current_session {
     shift;
     my %p       = @_;
     my $sid     = engine->read_session_id;
-    my $session = $sid ? Dancer::SharedData->session($sid) : undef;
+    my $session = undef;
     my $class   = ref(engine);
 
-    unless ( $session ) {
-        $session = $class->retrieve($sid) if $sid;
-        $session ||= $class->create;
-        Dancer::SharedData->session($session->id => $session);
+    $session = $class->retrieve($sid) if $sid;
+
+    if (not defined $session) {
+        $session = $class->create();
     }
 
     # Generate a session cookie; we want to do this regardless of whether the
@@ -81,7 +80,7 @@ Dancer::Session - session engine for the Dancer framework
 
 =head1 VERSION
 
-version 1.3137
+version 1.3139
 
 =head1 DESCRIPTION
 
