@@ -1,7 +1,7 @@
 package Dancer::SharedData;
 our $AUTHORITY = 'cpan:SUKRIA';
 # ABSTRACT: Shared-data singleton for Dancer
-$Dancer::SharedData::VERSION = '1.3137'; # TRIAL
+$Dancer::SharedData::VERSION = '1.3139'; # TRIAL
 use strict;
 use warnings;
 use Dancer::Timer;
@@ -16,16 +16,6 @@ Dancer::Factory::Hook->instance->install_hooks(
 my $vars = {};
 sub vars {$vars}
 
-# $session is an hash of the form $sid => the_session
-my $session = {};
-sub session { 
-    my $class = shift;
-
-    $session->{$_[0]} = $_[1] if @_ == 2;
-
-    return $session->{$_[0]};
-};
-
 sub var {
     my ($class, $key, $value) = @_;
     $vars->{$key} = $value if (@_ == 3);
@@ -66,7 +56,6 @@ sub reset_all {
 
     if (!$is_forward) {
         $vars = {};
-        $session = {};
     }
     undef $_request;
     undef $_headers;
@@ -88,7 +77,7 @@ Dancer::SharedData - Shared-data singleton for Dancer
 
 =head1 VERSION
 
-version 1.3137
+version 1.3139
 
 =head1 AUTHOR
 
